﻿using System;
using System.Text;
using System.Threading.Tasks;
using Nancy;
using Nancy.ErrorHandling;
using Nancy.Hosting.Self;

namespace Rest {
    internal class Program {
        public static void Main(string[] args){
            var hostConfigs = new HostConfiguration{
                UrlReservations = new UrlReservations{ CreateAutomatically = true }
            };
            // initialize an instance of NancyHost (found in the Nancy.Hosting.Self package)
            var host = new NancyHost(hostConfigs,new Uri("http://localhost:12345"));    
            host.Start(); // start hosting

            Console.ReadKey();    
            host.Stop(); // stop hosting
        }
    }
    
    public class Module : NancyModule
    {
        public Module()
        {
            Get("/greet/{name}", x => {
                return string.Concat("Hello ", x.name);
            });
            
            Get("/async", async _ => {
                await Task.Delay(TimeSpan.FromSeconds(3));
                return "Done";
            });
        }
    }
    
    // Кастомное 404 
    public class StatusCodeHandler : IStatusCodeHandler  
    {  
        private readonly IRootPathProvider _rootPathProvider;  
  
        public StatusCodeHandler(IRootPathProvider rootPathProvider)  
        {  
            _rootPathProvider = rootPathProvider;  
        }  
  
        // The HandleStatusCode() method checks if status code is HttpStatusCode.NotFound. Returning true tells Nancy that our StatusCodeHandler will handle the response to this status code.
        public bool HandlesStatusCode(HttpStatusCode statusCode, NancyContext context)  
        {  
            return statusCode == HttpStatusCode.NotFound;  
        }  
  
        public void Handle(HttpStatusCode statusCode, NancyContext context)  
        {  
            var response = (Response)@"{""message"": ""404 :(""}";

            response.ContentType = "application/json";

            context.Response =  response;
        }  
    }
}